[−][src]Crate coin_cbc
Coin CBC Rust bindings
This crate exposes safe and efficient bindings to the Coin CBC C API.
This project is distributed under the MIT License by Kardinal.
Re-exports
pub use raw::Sense; |
Modules
| raw | A raw and safe binding to the Coin CBC C API. |
Structs
| Col | A column identifier. |
| Model | A MILP model. |
| Row | A row identifier. |
| Solution | A solution to a MILP problem. |